@@ -38,18 +38,17 @@ orderby <- function(source,
                      ...,
                      rev_cols = NULL,
                      limit = NULL) {
+  UseMethod("orderby", source)
+}
+
+#' @export
+orderby.relop <- function(source,
+                    cols = NULL,
+                    ...,
+                    rev_cols = NULL,
+                    limit = NULL) {
   if(length(list(...))>0) {
-    stop("unexpected arguemnts")
-  }
-  if(is.data.frame(source)) {
-    tmp_name <- cdata::makeTempNameGenerator("rquery_tmp")()
-    dnode <- table_source(tmp_name, colnames(source))
-    dnode$data <- source
-    enode <- orderby(dnode,
-                     orderby = cols,
-                     rev_orderby = rev_cols,
-                     limit = limit)
-    return(enode)
+    stop("unexpected arguments")
   }
   have <- column_names(source)
   check_have_cols(have, c(cols, rev_cols), "rquery::orderby orderterms")
@@ -63,12 +62,32 @@ orderby <- function(source,
   r
 }
 
+#' @export
+orderby.data.frame <- function(source,
+                    cols = NULL,
+                    ...,
+                    rev_cols = NULL,
+                    limit = NULL) {
+  if(length(list(...))>0) {
+    stop("unexpected arguments")
+  }
+  tmp_name <- mkTempNameGenerator("rquery_tmp")()
+  dnode <- table_source(tmp_name, colnames(source))
+  dnode$data <- source
+  enode <- orderby(dnode,
+                   orderby = cols,
+                   rev_orderby = rev_cols,
+                   limit = limit)
+  return(enode)
+}
+
+
 
 
 #' @export
 format.relop_orderby <- function(x, ...) {
   if(length(list(...))>0) {
-    stop("unexpected arguemnts")
+    stop("unexpected arguments")
   }
   ot <- c(x$orderby)
   if(length(x$rev_orderby)>0) {
@@ -128,7 +147,7 @@ to_sql.relop_orderby <- function (x,
                                    append_cr = TRUE,
                                    using = NULL) {
   if(length(list(...))>0) {
-    stop("unexpected arguemnts")
+    stop("unexpected arguments")
   }
   cols1 <- column_names(x$source[[1]])
   cols <- vapply(cols1,
